@@ -16,7 +16,7 @@ stats::aggregate
 #' aggregate(nlist(x = 1:9))
 #' aggregate(nlist(y = 3:5, zz = matrix(1:9, 3)), fun = function(x) x[1])
 aggregate.nlist <- function(x, fun = mean, ...) {
-  deprecate_soft("0.1.1",
+  deprecate_warn("0.1.1",
     what = "nlist::aggregate.nlist()",
     with = "nlist::estimates.nlist()"
   )
@@ -37,7 +37,7 @@ aggregate.nlist <- function(x, fun = mean, ...) {
 #' @examples
 #' aggregate(nlists(nlist(x = 1:3), nlist(x = 2:4)))
 aggregate.nlists <- function(x, fun = mean, ..., by_chain = FALSE) {
-  deprecate_soft("0.1.1",
+  deprecate_warn("0.1.1",
     what = "nlist::aggregate.nlists()",
     with = "nlist::estimates.nlists()"
   )
