@@ -3,7 +3,8 @@ as_list_unnamed_default <- function(x, ...) {
   x <- as.list(x)
   names <- names(x)
   attributes(x) <- NULL
-  if(!is.null(names))
+  if (!is.null(names)) {
     names(x) <- names
+  }
   x
 }
